@@ -14,26 +14,26 @@ PY_WRAP_PREFIX = '__PY_BOND'
 class Python(Bond):
     LANG = 'Python'
 
-    def __init__(self, cmd="python", args="", xargs="", cwd=None, env=os.environ,
+    def __init__(self, cmd="python", args="-i", xargs="", cwd=None, env=os.environ,
                  trans_except=True, protocol=-1, timeout=None, logfile=None):
         cmd = ' '.join([cmd, args, xargs])
         proc = Spawn(cmd, cwd=cwd, env=env, timeout=timeout, logfile=logfile)
         try:
             proc.expect(PY_PROMPT)
-        except pexpect.ExceptionPexpect as e:
+        except pexpect.ExceptionPexpect:
             raise BondException(self.LANG, 'cannot get an interactive prompt using: ' + cmd)
 
         # inject our prelude
         code = pkg_resources.resource_string(__name__, PY_PRELUDE)
         code = code + "\n{PY_WRAP_PREFIX}_sendline()\n".format(PY_WRAP_PREFIX=PY_WRAP_PREFIX)
-        proc.sendline("exec({code})".format(code=repr(code)))
+        proc.sendline_noecho("exec({code})".format(code=repr(code)))
         try:
             proc.expect(r'\r\n{prompt}'.format(prompt=PY_PROMPT))
-        except pexpect.ExceptionPexpect as e:
+        except pexpect.ExceptionPexpect:
             raise BondException(self.LANG, 'cannot initialize interpreter')
 
         # start the inner repl
-        proc.sendline(r'{PY_WRAP_PREFIX}_start({trans_except}, {protocol});'.format(
+        proc.sendline_noecho(r'{PY_WRAP_PREFIX}_start({trans_except}, {protocol});'.format(
             PY_WRAP_PREFIX=PY_WRAP_PREFIX, trans_except=trans_except, protocol=protocol))
 
         self.protocol = protocol
